@@ -1,7 +1,6 @@
 package main
 
 import (
-	"fmt"
 	"github.com/tomwright/dasel/internal/command"
 	"os"
 )
@@ -10,7 +9,7 @@ func main() {
 	cmd := command.NewRootCMD()
 	command.ChangeDefaultCommand(cmd, "select", "-v", "--version", "help")
 	if err := cmd.Execute(); err != nil {
-		fmt.Println("Error: " + err.Error())
+		cmd.PrintErrln("Error:", err.Error())
 		os.Exit(1)
 	}
 }
