@@ -106,13 +106,19 @@ func nilValue() reflect.Value {
 }
 
 func unwrapValue(value reflect.Value) reflect.Value {
-	// value = reflect.Indirect(value)
 	if value.Kind() == reflect.Interface {
 		return value.Elem()
 	}
 	return value
 }
 
+func derefValue(value reflect.Value) reflect.Value {
+	if value.Kind() == reflect.Ptr {
+		return value.Elem()
+	}
+	return value
+}
+
 // New returns a new root node with the given value.
 func New(value interface{}) *Node {
 	rootNode := &Node{
